@@ -26,7 +26,6 @@
 #include <gtk/gtk.h>
 #include <packagekit-glib2/packagekit.h>
 
-#include "gpk-animated-icon.h"
 #include "gpk-enum.h"
 
 G_BEGIN_DECLS
@@ -70,9 +69,6 @@ gchar		*gpk_time_to_localised_string		(guint		 time_secs);
 gchar		*gpk_time_to_imprecise_string		(guint		 time_secs);
 gboolean	 gpk_check_privileged_user		(const gchar	*application_name,
 							 gboolean	 show_ui);
-gboolean	 gpk_set_animated_icon_from_status	(GpkAnimatedIcon *icon,
-							 PkStatusEnum	 status,
-							 GtkIconSize	 size);
 gchar		*gpk_strv_join_locale			(gchar		**array);
 GtkEntryCompletion *gpk_package_entry_completion_new	(void);
 gboolean	 gpk_window_set_size_request		(GtkWindow	*window,
@@ -82,7 +78,6 @@ gboolean	 gpk_window_set_parent_xid		(GtkWindow	*window,
 							 guint32	 xid);
 GPtrArray	*pk_strv_to_ptr_array			(gchar		**array)
 							 G_GNUC_WARN_UNUSED_RESULT;
-gchar		**pk_package_array_to_strv		(GPtrArray	*array);
 
 G_END_DECLS
 
